import { Controller } from '@hotwired/stimulus';
import { Turbo } from '@hotwired/turbo-rails';
import SlimSelect from 'slim-select';

export default class extends Controller {
  connect() {
    this.slimSelect = new SlimSelect({
      select: this.element,
      settings: {
        searchText: this.element.dataset.searchText,
        searchPlaceholder: this.element.dataset.searchPlaceholder,
      },
      events: {
        addable: function (value) {
          let csrfToken = document.querySelector('meta[name="csrf-token"]')?.getAttribute('content');

          return new Promise(resolve => {
            fetch('/store/users/add_hostname', {
              method: 'POST',
              headers: {
                Accept: 'text/vnd.turbo-stream.html, application/json',
                'Content-Type': 'application/json',
                'X-CSRF-Token': csrfToken,
              },
              body: JSON.stringify({ value: value }),
            })
              .then(response => {
                const contentType = response.headers.get('content-type');
                if (contentType && contentType.includes('text/vnd.turbo-stream.html')) {
                  response.text().then(html => {
                    document.documentElement.insertAdjacentHTML('beforeend', html);
                    resolve(true);
                  });
                } else if (contentType && contentType.includes('application/json')) {
                  response.json().then(data => {
                    if (data.valid) {
                      const updateEvent = new CustomEvent('cart-host-update', {
                        detail: { text: data.text, value: data.value },
                      });
                      document.dispatchEvent(updateEvent);
                      resolve({
                        text: data.text,
                        value: data.value,
                      });
                    } else {
                      resolve(false);
                    }
                  });
                } else {
                  resolve(false);
                }
              })
              .catch(() => {
                resolve(false);
              });
          });
        },
      },
    });

    document.addEventListener('cart-host-update', this.updateOptions.bind(this), false);
  }

  updateOptions(event) {
    if (!this.slimSelect.store.data.find(option => option.value === event.detail.value)) {
      let data = this.slimSelect.store.data.map(option => ({
        value: option.value,
        text: option.text,
      }));
      data.push({ value: event.detail.value, text: event.detail.text });
      this.slimSelect.setData(data);
    }
  }

  disconnect() {
    document.removeEventListener('cart-host-update', this.updateOptions.bind(this), false);
    this.slimSelect.destroy();
  }
}
