# frozen_string_literal: true

module Store
  module SetLocale
    extend ActiveSupport::Concern

    included do
      before_action :set_locale

      def set_locale
        locale = 'en'
        locale = request.env['HTTP_ACCEPT_LANGUAGE'].scan(/^[a-z]{2}/i).first if request.env['HTTP_ACCEPT_LANGUAGE'].present?
        locale = cookies[:locale] if cookies[:locale].present?
        locale = @user.locale if @user.present?
        update_cookie_locale(locale) if locale != cookies[:locale]

        I18n.locale = locale
      end

      def update_cookie_locale(locale)
        cookies[:locale] = {
          value: locale,
          expires: 1.year.from_now,
          secure: Rails.env.production?,
          httponly: true
        }
      end
    end
  end
end
