# frozen_string_literal: true

module Store
  module Api
    class AppsController < ::Store::ApiController
      include ::Api::Concerns::ErrorHandler
      respond_to :json

      skip_before_action :set_user

      def index
        p = params.to_unsafe_h.except(:format, :controller, :action, :uuid, :space, :auth_token)
        query = ::Search::AppsSearch.new(p)
        @records = query.search.paginate(page: params[:page])
        paginate @records, each_serializer: PublicAppSerializer
      end

      def show
        if (app = App.find_by(:$or => [{ id: params[:id] }, { package: params[:id] }]))
          code = nil
          if params[:token] && (peer = Peer.active.find_by(token: params[:token])) && (voucher = Voucher.find_by(host: peer.host, module: app.package, type: 'app'))
            code = voucher.code
          end
          render json: app, serializer: PublicAppSerializer, code:
        else
          render_json_error :not_found, :app_not_found
        end
      end
    end
  end
end
