# frozen_string_literal: true

module Store
  module Authentification
    class PasswordsController < Devise::PasswordsController
      include Store::SetLocale

      helper Store::Engine.helpers
      layout 'store/sign-in'

      def create
        self.resource = User.send_reset_password_instructions(resource_params)

        yield resource if block_given?

        if successfully_sent?(resource)
          respond_with({}, location: after_sending_reset_password_instructions_path_for(:user))
        else
          respond_with(resource)
        end
      end

      def update
        self.resource = User.reset_password_by_token(resource_params)
        yield resource if block_given?

        if resource.errors.empty?
          # resource.unlock_access! if unlockable?(resource)
          if User.sign_in_after_reset_password
            flash_message = resource.active_for_authentication? ? :updated : :updated_not_active
            set_flash_message!(:notice, flash_message)
            resource.after_database_authentication
            sign_in(:user, resource)
          else
            set_flash_message!(:notice, :updated_not_active)
          end
          respond_with(resource, location: after_resetting_password_path_for(resource))
        else
          set_minimum_password_length
          respond_with(resource)
        end
      end

      def after_sending_reset_password_instructions_path_for(_resource_or_scope)
        store.store_home_path
      end

      def after_resetting_password_path_for(_resource_or_scope)
        store.store_apps_path
      end

      def resource_params
        params.fetch(:user, {})
      end
    end
  end
end
