# frozen_string_literal: true

module Store
  module Authentification
    class RegistrationsController < Devise::RegistrationsController
      include Store::SetLocale

      helper Store::Engine.helpers
      layout 'store/sign-up'

      def new
        build_resource
        yield resource if block_given?
        @user = resource
        respond_with resource
      end

      def create
        build_resource(sign_up_params)

        resource.save
        @user = resource
        yield resource if block_given?
        if resource.persisted?
          expire_data_after_sign_in!
          resource.send_confirmation_instructions
          respond_with resource, location: after_inactive_sign_up_path_for(resource)
        else
          clean_up_passwords resource
          set_minimum_password_length
          respond_with resource
        end
      end

      def sign_up_params
        params.require(:user).permit(
          :login,
          :first_name,
          :last_name,
          :email,
          :phone_number,
          :password,
          :password_confirmation,
          :position
        )
      end

      def after_inactive_sign_up_path_for(_resource)
        store.store_user_confirmation_path
      end
    end
  end
end
