# frozen_string_literal: true

module Store
  module Authentification
    class SessionsController < Devise::SessionsController
      helper Store::Engine.helpers
      layout 'store/sign-in'
      include Store::SetLocale

      def create
        self.resource = warden.authenticate!(auth_options)

        set_flash_message!(:notice, :signed_in)
        sign_in(:user, resource)
        yield resource if block_given?

        respond_with resource, location: after_sign_in_path_for(resource)
      end

      private

      def auth_options
        { scope: :user, recall: "#{controller_path}#new" }
      end

      def after_sign_in_path_for(_resource_or_scope)
        return store.published_store_products_path if current_user.developer?
        return store.store_vouchers_path if current_user.customer?
        return store.store_admin_users_path if current_user.admin?

        store.store_home_path
      end

      def after_sign_out_path_for(_resource_or_scope)
        store.store_home_path
      end
    end
  end
end
