# frozen_string_literal: true

module Store
  class ErrorsController < ApplicationController
    skip_before_action :authenticate_user!

    def generate_error
      skip_authorization
      skip_policy_scope

      @user = current_user

      code = params[:code].to_i

      return render 'store/errors/generate_error', status: :ok if code.zero?

      case code
      when 404
        not_found
      when 403
        raise Pundit::NotAuthorizedError
      when 500
        raise StandardError, 'This is a test error'
      else
        render_error_500
      end
    end

    def not_found
      skip_authorization
      skip_policy_scope

      @user = current_user

      @hide_sidebar = true unless @user
      respond_to do |format|
        format.html do
          render 'store/errors/not_found', status: 200
        end
        format.turbo_stream do
          flash.now[:alert] = t('store.errors.404_notice')
          render turbo_stream: [
            turbo_stream.prepend(:flash_messages, partial: 'store/shared/flash_messages')
          ], status: :not_found
        end
      end
    end
  end
end
