# frozen_string_literal: true

module Store
  class UsersController < ApplicationController
    def edit_profile
      authorize @user, policy_class: Store::UserPolicy
      skip_policy_scope

      respond_to(&:html)
    end

    def update_profile
      authorize @user, policy_class: Store::UserPolicy
      skip_policy_scope

      if @user.update(user_params)
        I18n.locale = @user.locale
        flash[:notice] = t('store.edit_profile.profile_updated_successfully')

        render turbo_stream: [
          turbo_stream.reload
        ]
      else
        render :edit_profile
      end
    end

    def add_hostname
      authorize @user, policy_class: Store::UserPolicy
      skip_policy_scope

      hostname = params[:value].to_s.downcase
      @user.hostnames = [hostname] + @user.hostnames
      @user.save

      return render json: { valid: true, text: @user.hostnames.first, value: @user.hostnames.first } if @user.save

      flash.now[:alert] = t('store.product.errors.invalid_hostname', hostname:)

      render turbo_stream: [
        turbo_stream.prepend(:flash_messages, partial: 'store/shared/flash_messages')
      ], status: :unprocessable_entity
    end

    private

    def user_params
      cleaned_params = params.require(:user).permit(
        :login,
        :first_name,
        :last_name,
        :email,
        :phone_number,
        :position,
        :default_hostname,
        :locale,
        hostnames: []
      )

      cleaned_params[:hostnames] = cleaned_params[:hostnames].to_array.map(&:downcase).uniq.compact.reject(&:empty?) if @user.customer?
      cleaned_params
    end
  end
end
