# frozen_string_literal: true

module Store
  class VouchersController < ApplicationController
    before_action :check_if_customer

    def index
      authorize Voucher
      @vouchers = find_models(policy_scope(Voucher).where(user: @user, :code.ne => nil), default_sort_by: 'product_title')

      respond_to do |format|
        format.html
        format.turbo_stream do
          render turbo_stream: [
            turbo_stream.update(:app_content, render_to_string(template: 'store/vouchers/index', layout: false, formats: [:html])),
            turbo_stream.prepend(:flash_messages, partial: 'store/shared/flash_messages'),
            turbo_stream.update('cart-link', partial: 'store/shared/cart_link'),
            turbo_stream.push_state(request.url)
          ]
        end
      end
    end

    def more
      authorize Voucher
      @vouchers = find_models(policy_scope(Voucher).where(user: @user, :code.ne => nil), default_sort_by: 'product_title')
      respond_to(&:turbo_stream)
    end
  end
end
