# frozen_string_literal: true

module Store
  module ApplicationHelper
    def store_importmap_tags(entry_point = 'application')
      safe_join [
        javascript_inline_importmap_tag(Store.configuration.importmap.to_json(resolver: self)),
        javascript_importmap_module_preload_tags(Store.configuration.importmap),
        javascript_import_module_tag(entry_point)
      ].compact, "\n"
    end

    def test_helper_method(test)
      "This is a test helper method #{test}"
    end

    def flash_class(type)
      case type
      when 'notice'
        'indigo'
      when 'alert'
        'rose'
      when 'warning'
        'amber'
      when 'success'
        'emerald'
      else
        'gray'
      end
    end

    def determine_dashboard_url(user)
      return store_home_path unless user

      if user.customer?
        store_vouchers_path
      elsif user.developer?
        published_store_products_path
      elsif user.admin?
        store_admin_users_path
      else
        store_home_path
      end
    end

    def format_price(price)
      number_to_currency(price, unit: '€', format: '%n %u')
    end

    def format_product_price(product)
      return t('store.product.free') if product.free

      format_price(product.price)
    end
  end
end
