# frozen_string_literal: true

module Store
  class Voucher
    include Mongoid::Document
    include Mongoid::Timestamps

    field :code, type: String
    field :host, type: String
    field :module, type: String
    field :type, type: String
    field :active, type: Mongoid::Boolean, default: false
    field :product_title, type: String
    field :end_date, type: Date

    belongs_to :product, class_name: 'Store::Product', optional: true
    belongs_to :order, class_name: 'Store::Order', optional: true
    belongs_to :customer, class_name: 'Store::Customer', optional: true
    belongs_to :user, optional: true

    after_save :update_order_price

    def update_order_price
      return unless order && saved_change_to_attribute(:order_id)

      order.calc_price
      order.save
    end

    def gen_code
      self.code = product.gen_code_for(host)
      self.module = product.package
      self.type = product.type
      self.product_title = product.title
      self.end_date = Date.today + product.duration_count.send(product.duration_unit)
      self.active = true
    end
  end
end
