# frozen_string_literal: true

User.class_eval do
  field :hostnames, type: Array, default: []
  field :position, type: String
  field :locale, type: String, default: 'en'
  field :blocked_at, type: Time, default: nil

  validates_presence_of :login, :first_name, :last_name
  validate :validate_hostnames

  before_save :before_save_store

  def validate_hostnames
    domain_regex = /\A(?:[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?\.)+[a-z0-9][a-z0-9-]{0,61}[a-z0-9]\z/i
    hostnames.each do |hostname|
      errors.add(:hostnames, I18n.t('store.product.errors.invalid_hostname', hostname:)) unless hostname.match?(domain_regex)
    end
  end

  def active_for_authentication?
    super && blocked_at.nil?
  end

  def before_save_store
    self.auth_roles = [position] if will_save_change_to_attribute?(:position)
  end

  def self.possible_roles
    %w[developer customer]
  end

  def self.possible_involvements
    %w[Full-time Part-time Freelancer]
  end

  def self.possible_hosts
    %w[GitHub GitLab Bitbucket]
  end

  def developer?
    auth_roles&.include?('developer')
  end

  def customer?
    auth_roles&.include?('customer')
  end

  def admin?
    roles&.include?('Administrator')
  end

  def user_cart
    @user_cart ||= Store::Order.order_by(created_at: :desc).find_or_create_by(user_id: id, is_cart: true)
  end

  def block
    update(blocked_at: Time.current)
  end

  def unblock
    update(blocked_at: nil)
  end
end
