# frozen_string_literal: true

module Store
  class AppPolicy
    attr_reader :user, :app

    def initialize(user, app)
      @user = user
      @app = app
    end

    def index?
      user&.developer? || user&.admin?
    end

    def more?
      index?
    end

    def sort?
      index?
    end

    def update?
      user&.admin? || app.user == user
    end

    def edit?
      update?
    end

    def create?
      user&.developer? || user&.admin?
    end

    def new?
      create?
    end

    def create_product?
      user&.admin? || app.user == user
    end

    def new_product?
      create_product?
    end

    class Scope
      attr_reader :user, :scope

      def initialize(user, scope)
        @user = user
        @scope = scope
      end

      def resolve
        if user&.admin?
          scope.all
        else
          scope.where(user:)
        end
      end
    end
  end
end
