# frozen_string_literal: true

module Store
  class OrderPolicy
    attr_reader :user, :order

    def initialize(user, order)
      @user = user
      @order = order
    end

    def cart?
      user.customer? && order.user == user && order.is_cart
    end

    def buy?
      cart?
    end

    def add_to_cart?
      cart?
    end

    def remove_from_cart?
      cart?
    end

    def checkout?
      cart?
    end

    def index?
      user&.customer? || user&.admin?
    end

    def more?
      index?
    end

    def sort?
      index?
    end

    def show?
      order&.user == user || user&.admin?
    end

    class Scope
      attr_reader :user, :scope

      def initialize(user, scope)
        @user = user
        @scope = scope
      end

      def resolve
        if user&.admin?
          scope.all
        else
          scope.where(user:)
        end
      end
    end
  end
end
