# frozen_string_literal: true

module Store
  class ProductPolicy
    attr_reader :user, :product

    def initialize(user, product)
      @user = user
      @product = product
    end

    def index?
      user&.admin?
    end

    def more?
      index?
    end

    def sort?
      index?
    end

    def admin_edit?
      user&.admin?
    end

    def admin_update?
      admin_edit?
    end

    def publish?
      admin_edit?
    end

    def promote?
      admin_edit?
    end

    def unpromote?
      promote?
    end

    def published?
      user&.developer? || user&.admin?
    end

    def more_published?
      published?
    end

    def sort_published?
      published?
    end

    def unpublished?
      user&.developer? || user&.admin?
    end

    def more_unpublished?
      unpublished?
    end

    def sort_unpublished?
      unpublished?
    end

    def product_details?
      product.user == user || product.published? || user&.admin?
    end

    def update?
      (user&.developer? && product.user == user && !product.published?) || user&.admin?
    end

    def edit?
      update?
    end

    def unpublish?
      (user&.developer? && product.user == user) || user&.admin?
    end

    def ask_to_publish?
      unpublish?
    end

    class Scope
      attr_reader :user, :scope

      def initialize(user, scope)
        @user = user
        @scope = scope
      end

      def resolve
        if user&.admin?
          scope.all
        elsif user&.developer?
          scope.where(:$or => [{ user: }, { :published_at.ne => nil }])
        else
          scope.where({ :published_at.ne => nil })
        end
      end
    end
  end
end
