# frozen_string_literal: true

module Store
  class UserPolicy
    attr_reader :user

    def initialize(user, record_user)
      @user = user
      @record_user = record_user
    end

    def index?
      user&.admin?
    end

    def more?
      index?
    end

    def sort?
      index?
    end

    def edit?
      user&.admin?
    end

    def update?
      edit?
    end

    def block?
      user&.admin?
    end

    def unblock?
      block?
    end

    def edit_profile?
      user == @record_user || user&.admin?
    end

    def update_profile?
      edit_profile?
    end

    def add_hostname?
      edit_profile?
    end

    class Scope
      attr_reader :user, :scope

      def initialize(user, scope)
        @user = user
        @scope = scope
      end

      def resolve
        if user&.admin?
          scope.all
        else
          scope.where(id: user.id)
        end
      end
    end
  end
end
