# frozen_string_literal: true

module Store
  module Search
    class CustomersSearch < ::Search::BaseSearch
      def initialize(params, options = {})
        @main_key = 'title'
        super(params, options)
      end

      def get_context # rubocop:disable Naming/AccessorMethodName
        @context = 'Store::CustomerSearch'
        @context_class = Store::Customer
      end

      def run_filters(query)
        if @prefix.blank?
          query = build_customers_filter(query)
          query = build_sounds_filter(query)
        end
        super(query)
      end

      private

      def build_customers_filter(query)
        query['payment_method'] = query['payment_method'].to_s unless query['payment_method'].blank?

        query['host'] = query['host'].to_bool unless query['host'].blank?

        query
      end
    end
  end
end
