# frozen_string_literal: true

Store::Engine.routes.draw do # rubocop:disable Metrics/BlockLength
  scope path: '/store', as: 'store' do # rubocop:disable Metrics/BlockLength
    devise_for :users, class_name: '::User', controllers: {
      confirmations: 'store/authentification/confirmations',
      passwords: 'store/authentification/passwords',
      registrations: 'store/authentification/registrations',
      sessions: 'store/authentification/sessions'
    }

    get '/', to: 'home#index', as: 'home'
    put 'update_locale', to: 'home#update_locale'
    get 'pre_sign_up', to: 'authentification/sign_up#pre_sign_up'
    get 'search', to: 'home#search'
    get 'users/edit_profile', to: 'users#edit_profile'
    put 'users/update_profile', to: 'users#update_profile'
    post 'users/add_hostname', to: 'users#add_hostname'

    resources :apps, only: %i[index new create edit update] do
      collection do
        get 'more'
        get 'sort'
      end
      member do
        get 'new_product'
        post 'create_product'
      end
    end

    resources :products, only: %i[edit update] do
      collection do
        get 'published'
        get 'more_published'
        get 'sort_published'
        get 'unpublished'
        get 'sort_unpublished'
        get 'more_unpublished'
        post 'add_picture'
      end

      member do
        get 'product_details', to: 'home#product_details'
        get 'more_reviews', to: 'home#more_reviews'
        post 'create_review', to: 'home#create_review'
        delete 'destroy_review', to: 'home#destroy_review'
        put 'unpublish'
        put 'ask_to_publish'
      end
    end

    resources :orders, only: %i[index] do
      collection do
        post 'add_to_cart/:product_id', to: 'orders#add_to_cart', as: 'add_to_cart'
        post 'buy/:product_id', to: 'orders#buy', as: 'buy'
        delete 'remove_from_cart/:voucher_id', to: 'orders#remove_from_cart', as: 'remove_from_cart'
        get 'cart'
        put 'checkout'
        get 'more'
      end
      member do
        get 'show'
      end
    end

    resources :vouchers, only: %i[index] do
      collection do
        get 'more'
      end
    end

    namespace :admin do
      resources :users, only: %i[index edit update] do
        collection do
          get 'more'
          get 'sort'
          get 'search'
        end
        member do
          put 'block'
          put 'unblock'
        end
      end

      resources :products, only: %i[index] do
        collection do
          get 'more'
          get 'sort'
          get 'search'
        end
        member do
          put 'publish'
          put 'unpublish'
          put 'promote'
          put 'unpromote'
          put 'publish'
          put 'unpublish'
          get 'admin_edit'
          put 'admin_update'
        end
      end
    end

    get 'generate_error', to: 'errors#generate_error'
    post 'generate_error', to: 'errors#generate_error'
    get '*path', to: 'errors#not_found'
  end

  namespace :api do
    get 'store/apps', to: 'apps#index', format: 'json'
    get 'store/apps/:id', to: 'apps#show', format: 'json'

    namespace :store do
      resources :vouchers, only: %i[index]
    end
  end
end
