import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is an user', () => {
  cy.app('clean');
  cy.appScenario('with_admin');
});

When('I click on sign in button', () => {
  cy.get('#sign-in-button').click();
});

When('I use the proper login', () => {
  cy.storeLogin('admin@cypress.fr', 'Password1!');
});

When('I use the wrong login', () => {
  cy.storeLogin('admin@cypress.fr', 'wrong_password');
});

When('I visit the store', () => {
  cy.visit(`${Cypress.config().baseUrl}/store`);
});

Then('I am logged in', () => {
  cy.get('#sign-in-button').should('not.exist');
  cy.get('#sign-out-button').should('exist');
});

When('I visit the store sign in page', () => {
  cy.visit(`${Cypress.config().baseUrl}/store/users/sign_in`);
});

When('I click on forgot password link', () => {
  cy.get('a#forgot-password-link').click();
});

When('I use the proper email', () => {
  cy.get('input#forgot_passwor_email').type('admin@cypress.fr');
  cy.get('input#forgot_password_submit').click();
});

When('I use the wrong email', () => {
  cy.get('input#forgot_passwor_email').type('test@email.com');
  cy.get('input#forgot_password_submit').click();
});

Then('I see error message', () => {
  cy.get('#error_explanation').should('exist');
});

When('I visit the store password reset page', () => {
  cy.visit(`${Cypress.config().baseUrl}/store/users/password/edit?reset_password_token=123456`);
});

When('I visit the store password reset page with a wrong token', () => {
  cy.visit(`${Cypress.config().baseUrl}/store/users/password/edit?reset_password_token=wrong_token`);
});

Given('There is an user with a reset_password_token', () => {
  cy.app('clean');
  cy.appScenario('admin_with_reset_password_token');
});

When('I add a new password', () => {
  cy.get('input#new_password').type('Password1!234');
  cy.get('input#password_confirmation').type('Password1!234');
  cy.get('input#password_submit').click();
});

When('I add a new password with wrong confirmation', () => {
  cy.get('input#new_password').type('Password1!234');
  cy.get('input#password_confirmation').type('lol');
  cy.get('input#password_submit').click();
});

When('I add a new password with too simple password', () => {
  cy.get('input#new_password').type('Password1');
  cy.get('input#password_confirmation').type('Password1');
  cy.get('input#password_submit').click();
});

When('I sign out', () => {
  cy.get('#sign-out-button').click({ force: true });
});

Then('I am not logged in', () => {
  cy.get('#sign-in-button').should('exist');
  cy.get('#sign-out-button').should('not.exist');
});

Then('I see the page in french', () => {
  cy.get('#language-changer').should('have.value', 'fr');
  cy.get("form input[type='submit']").contains('Se connecter');
});

Then('I see the page in english', () => {
  cy.get('#language-changer').should('have.value', 'en');
  cy.get("form input[type='submit']").contains('Sign in');
});
