import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is some products unpublished', () => {
  cy.appFactories([['create_list', 'product_with_app', 3, { user_id: '1' }]]);
  cy.appFactories([['create', 'product_with_app', 'published', { user_id: 'other_user_id' }]]);
  cy.appFactories([['create', 'product_with_app', 'published', { user_id: '1' }]]);
});

Given('There is a lot of products unpublish', () => {
  cy.appFactories([['create_list', 'product_with_app', 30, { user_id: '1' }]]);
});

Given('There is one products unpublish', () => {
  cy.appFactories([['create', 'product_with_app', { id: '1', user_id: '1' }]]);
});

When('I click on a product', () => {
  cy.get('#model_table tbody a').first().click();
});

When('I click on the action show details', () => {
  cy.get('#model_table tbody tr').first().find(`a[href*="details"]`).first().should('be.visible').click();
});

When('I click on the action to edit', () => {
  cy.get('#model_table tbody tr').first().find(`a[href*="edit"]`).first().should('be.visible').click();
});

When('I remove the product duration', () => {
  cy.get('input[name="product[duration_count]"]').clear();
  cy.get('input[type="submit"]').click();
});

When('I fill the product duration', () => {
  cy.get('input[name="product[duration_count]"]').type(100);
  cy.get('input[type="submit"]').click();
});

When('I click on the action to ask to publish', () => {
  cy.get('#model_table tbody tr').first().find(`a[href*="ask_to_publish"]`).first().should('be.visible').click();
});

When('I click on the sort by', () => {
  cy.get('#model_table thead th a').first().click();
});

When('I add a picture', () => {
  cy.get('button[data-action="click->product-file-upload#addNewPicture"]').click();
  cy.get('input[name="asset[file]"]').selectFile('cypress/fixtures/dog.jpg', { force: true });
  cy.wait(500);
  cy.get('input[type="submit"]').click();
});

When('I remove a picture', () => {
  cy.get('.product-picture').first().find('button').click();
  cy.get('input[type="submit"]').click();
});

When('I reorder the pictures', () => {
  cy.get('.product-picture:last img')
    .invoke('attr', 'src')
    .then(lastPictureUrl => {
      Cypress.env('lastPictureUrl', lastPictureUrl);
    });
  cy.get('.product-picture:last').drag('.product-picture:first');
  cy.get('input[type="submit"]').click();
});

Then('I see my unpublished products', () => {
  cy.get('#model_table tbody tr').should('have.length', 3);
});

Then('I see all my unpublished products', () => {
  cy.get('#model_table tbody tr').should('have.length', 30);
});

Then('I should see the error on the product duration', () => {
  cy.get('.field_with_errors').should('be.visible');
});

Then('The product is unpublished', () => {
  cy.get('#model_table tbody tr').first().find(`td`).eq(2).should('have.text', 'true');
});

Then('The products are sorted', () => {
  cy.get('#model_table tbody tr td').first().contains('3');
});

Then('I see the new picture', () => {
  cy.get('#product-pictures img').should('have.length', 4);
});

Then('I not see the picture', () => {
  cy.get('#product-pictures img').should('have.length', 2);
});

Then('I see the last picture first', () => {
  cy.get('#product-pictures img').first().should('have.attr', 'src', Cypress.env('lastPictureUrl'));
});
