import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('I am guest', () => {
  cy.app('clean');
});

Given('I am a logged in customer', () => {
  cy.app('clean');
  cy.appFactories([
    [
      'create',
      'user',
      {
        id: '1',
        email: 'johndoe@test.com',
        password: 'Password1!',
        position: 'customer',
        authentication_token: 'johns_token',
        hostnames: ['www.example.com', 'www.google.com'],
      },
    ],
  ]);
  cy.addAuthHeader('johns_token');
});

Given('I am not developer', () => {
  cy.app('clean');
  cy.appFactories([
    [
      'create',
      'user',
      {
        email: 'johndoe@test.com',
        password: 'Password1!',
        position: 'customer',
        authentication_token: 'johns_token',
      },
    ],
  ]);
  cy.addAuthHeader('johns_token');
});

Given('I am already sign up as a developer', () => {
  cy.app('clean');
  cy.appFactories([
    [
      'create',
      'user',
      {
        email: 'johndoe@test.com',
        password: 'Password1!',
        position: 'developer',
        authentication_token: 'johns_token',
      },
    ],
  ]);
});

Given('I am a logged in developer', () => {
  cy.app('clean');
  cy.appFactories([
    [
      'create',
      'user',
      {
        id: '1',
        email: 'johndoe@test.com',
        password: 'Password1!',
        position: 'developer',
        authentication_token: 'johns_token',
      },
    ],
  ]);
  cy.addAuthHeader('johns_token');
});

Given('I am a logged in admin', () => {
  cy.app('clean');
  cy.appFactories([
    [
      'create',
      'user',
      {
        id: '1',
        email: 'admin@test.com',
        password: 'Password1!',
        roles: ['Administrator'],
        authentication_token: 'johns_token',
      },
    ],
  ]);
  cy.addAuthHeader('johns_token');
});

When('I scroll down', () => {
  const maxScrolls = 10;
  let currentScroll = 0;

  function scrollAndWait() {
    if (currentScroll < maxScrolls) {
      cy.scrollTo('bottom');
      cy.wait(500);
      currentScroll++;
      scrollAndWait();
    }
  }

  scrollAndWait();
});

When('I visit the url {word}', url => {
  let headers = {};
  if (Cypress.env('auth-user-token')) {
    headers = {
      'X-auth-user-token': Cypress.env('auth-user-token'),
    };
  }
  cy.visit({
    url: `${Cypress.config().baseUrl}${url}`,
    failOnStatusCode: false,
    headers,
  });
});

When('I click on the action to return', () => {
  cy.wait(500);
  cy.get('#return-button').click();
});

Then('I change the language to {string}', locale => {
  cy.get('#language-changer').select(locale);
});

Then('The url is {word}', url => {
  cy.url().should('eq', `${Cypress.config().baseUrl}${url}`);
});

Then('The url should match {string}', urlPattern => {
  const dynamicUrl = urlPattern.replace(/\*/g, '.*');
  const regex = new RegExp(`^${Cypress.config().baseUrl}${dynamicUrl}$`);
  cy.url().should('match', regex);
});

Then('I should see a notification {string}', text => {
  cy.get('#flash_messages').should('contain', text);
});

Then('There is a sign in error', () => {
  cy.get('#sign-in-errors').should('exist');
});

Then('I should see form errors', () => {
  cy.get('.field_with_errors').should('be.visible');
});

Then('I see and access denied error', () => {
  cy.get('#app_content').contains('Access denied');
});

