# frozen_string_literal: true

require 'store/version'
require 'store/engine'
require 'store/railtie'
require 'importmap-rails'

module Store
  class << self
    attr_accessor :configuration
  end

  class Configuration
    attr_accessor :session_expiration, :token_expiration, :secret_key, :tailwind_content, :importmap

    def initialize
      @session_expiration = 2.hours
      @token_expiration = 15.minutes
      @secret_key = nil
      @importmap = Importmap::Map.new

      @tailwind_content = [
        "#{Store::Engine.root}/app/views/**/*",
        "#{Store::Engine.root}/app/helpers/**/*",
        "#{Store::Engine.root}/app/controllers/**/*",
        "#{Store::Engine.root}/app/javascript/**/*.js",
        "#{Store::Engine.root}/app/assets/**/application.tailwind.css"
      ]
    end

    def draw_importmap
      config_path = Engine.root.join('config/importmap.rb')
      config_code = File.read(config_path)
      @importmap.draw do
        eval(config_code, binding, config_path.to_s) # rubocop:disable Security/Eval
      end
    end
  end

  def self.init_config
    self.configuration ||= Configuration.new
  end

  def self.configure
    init_config
    yield(configuration)
  end
end

Store.init_config
