# frozen_string_literal: true

require_relative '../../app/helpers/store/application_helper'
module Store
  class Engine < ::Rails::Engine
    isolate_namespace Store

    config.assets.paths << Engine.root.join('vendor/javascript')
    config.autoload_paths << File.expand_path('app/components/store', __dir__)

    initializer 'store.importmap', before: 'importmap' do |app|
      app.config.importmap.cache_sweepers << Engine.root.join('app/assets/javascripts')
      app.config.importmap.paths << Engine.root.join('config/initializers/importmap.rb')

      ActiveSupport.on_load(:action_controller_base) do
        before_action do
          Store.configuration.draw_importmap if app.config.importmap.sweep_cache && Rails.application.importmap.cache_sweeper.updated?
        end
      end
    end

    initializer 'store.load_overrides' do
      Rails.application.config.to_prepare do
        overrides_path = Engine.root.join('app', 'overrides', '**', '*.rb')

        Dir.glob(overrides_path).each do |override_file|
          load override_file
        end
      end
    end

    initializer 'store.lookbook' do |app|
      base_preview_paths = Engine.root.join('test', 'components', 'previews')
      preview_paths = Dir.glob(base_preview_paths)

      app.config.lookbook.preview_paths ||= []
      app.config.view_component.preview_paths ||= []

      preview_paths.each do |preview_path|
        app.config.lookbook.preview_paths << preview_path
        app.config.view_component.preview_paths << preview_path
      end
    end
  end
end
