# frozen_string_literal: true

require 'rails_helper'

module Store
  describe Api::AppsController, type: :api do
    routes { Store::Engine.routes }
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper

    let!(:admin) { create(:administrator) }

    let!(:responsible) { create(:user) }
    let!(:user) { create(:user) }

    let!(:app1) { create(:app, name: 'email', package: 'email', user: :admin) }
    let!(:app2) { create(:app, name: 'files', package: 'files', user: :admin) }
    let!(:app3) { create(:app, name: 'todo', package: 'todo', user: :user) }

    let!(:voucher) { create(:voucher, host: 'rec.plugandwork.fr', module: 'todo', type: 'app', code: 'okcool') }

    let!(:peer) { create(:peer, active: true, host: 'rec.plugandwork.fr', token: '123') }

    describe 'GET /apps' do
      context 'as guest' do
        before :each do
          get 'index'
        end

        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty

          expect(json['data'].length).to eq(4)
          expect(json['meta']['pagination']).to be_present
          expect(json['meta']['pagination']['total_objects']).to eq(4)
        end
      end
    end

    describe 'GET /apps/:id' do
      context 'as guest' do
        before :each do
          get :show, params: { id: app1.id.to_s }
        end

        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end

        it 'returns valid JSON' do
          expect(json['data']['id']).to eq(app1.id.to_s)
          expect(json['data']['attributes']['name']).to eq(app1.name)
          expect(json['data']['attributes']['code']).to be_nil
        end
      end
    end

    describe 'GET /apps/:id' do
      context 'as peer' do
        before :each do
          get 'show', params: { id: app3.id, token: peer.token }
        end

        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end

        it 'returns valid JSON' do
          expect(json['data']['id']).to eq(app3.id.to_s)
          expect(json['data']['attributes']['name']).to eq(app3.name)
          expect(json['data']['attributes']['code']).to eq(voucher.code)
        end
      end
    end
  end
end
