# frozen_string_literal: true

require 'faker'

FactoryBot.define do
  factory :product, class: Store::Product do
    title { Faker::App.unique.name }
    description { Faker::Lorem.paragraphs(number: 4).join("\n\n") }
    price { rand(1..100) }
    type { 'app' }
    package { %w[emails task].sample }
  end

  factory :product_with_app, class: Store::Product do
    picture_ids do
      3.times.map do
        file = Dir.glob(Store::Engine.root.join('app/assets/images/store/product_picture_url_samples/*')).sample
        Asset.create(name: File.basename(file), file:).id
      end
    end

    initialize_with do
      app = create(:store_app)
      user = create(:user)
      product = app.to_product(rand(1..100))
      product.user_id = user.id
      product
    end

    trait :with_reviews do
      transient do
        reviews_count { 5 }
      end

      after(:create) do |product, evaluator|
        evaluator.reviews_count.times do
          user = create(:user)
          create(:store_review, product:, user:)
        end
      end
    end

    trait :published do
      published_at { Faker::Time.between(from: 10.days.ago, to: Time.now) }
    end
  end
end
