# frozen_string_literal: true

require 'rails_helper'

RSpec.describe(Store::Product, type: :model) do
  it 'has a valid factory' do
    expect(FactoryBot.create(:product, price: 0)).to be_valid
  end

  it 'has a valid factory product_with_app' do
    expect(FactoryBot.create(:product_with_app)).to be_valid
  end

  # describe '#order basics' do
  #   let!(:user1) { create(:user) }
  #   let!(:product1) { create(:product, package: 'emails', price: 100) }
  #   let!(:customer) { create(:customer) }
  #   let!(:order) { create(:order, customer:, host: 'rec.plugandwork.fr') }

  #   it 'put products in order' do
  #     expect(order).to be_valid
  #     order.product_ids = [product1.id]
  #     order.save
  #     expect(order.reload.products.size).to eq 1

  #     order.payment_status = 'paid'
  #     order.save
  #     expect(order.reload.vouchers.size).to eq 1

  #     expect(order.vouchers.first.code).to_not be_blank
  #   end
  # end

  # describe '#product from app' do
  #   let!(:app) { create(:app, package: 'emails', type: 'view') }

  #   it 'has to be invalid without price' do
  #     product = app.to_product(nil)
  #     expect(product).to_not be_valid
  #   end

  #   it 'has to be valid with price' do
  #     product = app.to_product(1000)
  #     expect(product).to be_valid
  #     expect(product.price).to eq(1000)
  #     expect(product.title).to eq(app.name)
  #   end
  # end

  # describe '#order from app workflow for free products' do
  #   let!(:user1) { create(:user) }
  #   let!(:app) { create(:app, package: 'emails', type: 'view') }
  #   let!(:product1) { create(:product, title: '1 year emails', package: 'emails', price: 0) }
  #   let!(:product2) { create(:product, title: '1 year files', package: 'files', price: 0) }
  #   let!(:customer) { create(:customer) }
  #   let!(:order) { create(:order, customer:, host: 'rec.plugandwork.fr') }

  #   it 'put products in order and get vouchers' do
  #     expect(order).to be_valid
  #     order.product_ids = [product1.id, product2.id]
  #     order.save
  #     order.reload
  #     expect(order.products.size).to eq 2
  #     expect(order.total_price).to eq 0.0
  #     expect(order.payment_status).to eq 'paid'

  #     expect(order.vouchers.size).to eq 2

  #     expect(order.vouchers.first.code).to_not be_blank
  #   end
  # end

  # describe '#order from app workflow for products' do
  #   let!(:user1) { create(:user) }
  #   let!(:app) { create(:app, package: 'emails', type: 'view') }
  #   let!(:product1) { create(:product, title: '1 year emails', package: 'emails', price: 100) }
  #   let!(:product2) { create(:product, title: '1 year files', package: 'files', price: 200) }
  #   let!(:customer) { create(:customer) }
  #   let!(:order) { create(:order, customer:, host: 'rec.plugandwork.fr', product_ids: [product1.id, product2.id]) }

  #   it 'put products in order and get vouchers' do
  #     expect(order).to be_valid
  #     order.reload
  #     expect(order.products.size).to eq 2
  #     expect(order.payment_amount).to eq 0.0
  #     expect(order.total_price).to eq 300.0
  #     expect(order.payment_status).to eq 'not_processed'

  #     expect(order.vouchers.size).to eq 0
  #   end
  # end

  describe 'update_rating' do
    let!(:default_rating_details) { { 1 => 0, 2 => 0, 3 => 0, 4 => 0, 5 => 0 }.stringify_keys }
    context 'by default' do
      let!(:product) { create(:product_with_app) }

      it 'has a rating of 0' do
        expect(product.reload.rating).to eq(0)
        expect(product.rating_count).to eq(0)
        expect(product.rating_details).to eq(default_rating_details)
      end
    end

    context 'with reviews' do
      let!(:product) { create(:product_with_app, :with_reviews, reviews_count: 10) }

      it 'has a rating' do
        expect(product.reload.rating).not_to eq(0)
        expect(product.rating_count).to eq(10)
        expect(product.rating_details).not_to eq(default_rating_details)
      end

      it 'when creating a new review' do
        before_rating = product.reload.rating
        number_of_5_ratings = product.rating_details['5']
        user = create(:user)
        create(:store_review, product:, user:, rating: 5)
        expect(product.reload.rating_count).to eq(11)
        expect(product.rating).to eq(((before_rating * 10 + 5) / 11.0).round(2))
        expect(product.rating_details['5']).to eq(number_of_5_ratings + 1)
      end

      it 'when updating a review' do
        review = Store::Review.find_by(:rating.ne => 5)
        review_rating = review.rating
        before_rating = product.reload.rating
        number_of_5_ratings = product.rating_details['5']
        review.update(rating: 5)
        expect(product.reload.rating).to eq((((before_rating * 10) - review_rating + 5) / 10.0).round(2))
        expect(product.reload.rating_count).to eq(10)
        expect(product.rating_details['5']).to eq(number_of_5_ratings + 1)
      end

      it 'when deleting a review' do
        review = Store::Review.first
        review_rating = review.rating
        before_rating = product.reload.rating
        number_of_x_ratings = product.rating_details[review_rating.to_s]
        review.destroy
        expect(product.reload.rating).to eq((((before_rating * 10) - review_rating) / 9.0).round(2))
        expect(product.reload.rating_count).to eq(9)
        expect(product.rating_details[review_rating.to_s]).to eq(number_of_x_ratings - 1)
      end
    end
  end

  describe 'pictures' do
    let!(:product) { create(:product_with_app) }

    it 'has a main picture' do
      expect(product.main_picture_url).not_to be_blank
      expect(product.main_picture_url).not_to include('no_preview')
    end

    it 'has picture_url' do
      expect(product.reload.picture_urls.length).to eq(3)
    end

    it 'can remove _picture' do
      product.update(picture_ids: [])

      expect(product.reload.main_picture_url).to eq(nil)
      expect(Asset.count).to eq(0)
    end
  end
end
