# frozen_string_literal: true

require 'rails_helper'

RSpec.describe(Store::Review, type: :model) do
  it 'has a valid factory' do
    product = FactoryBot.create(:product)
    user = FactoryBot.create(:user)
    expect(FactoryBot.create(:store_review, product:, user:)).to be_valid
  end

  it 'is invalid without a rating' do
    review = FactoryBot.build(:store_review, rating: nil)
    review.valid?
    expect(review.errors[:rating]).not_to be_empty
  end

  it 'is invalid without a user' do
    review = FactoryBot.build(:store_review, user: nil)
    review.valid?
    expect(review.errors[:user_id]).not_to be_empty
  end

  it 'is invalid without a product' do
    review = FactoryBot.build(:store_review, product: nil)
    review.valid?
    expect(review.errors[:product_id]).not_to be_empty
  end

  it 'is invalid with a rating greater than 5' do
    review = FactoryBot.build(:store_review, rating: 6)
    review.valid?
    expect(review.errors[:rating]).not_to be_empty
  end

  it 'is invalid with a rating less than 1' do
    review = FactoryBot.build(:store_review, rating: 0)
    review.valid?
    expect(review.errors[:rating]).not_to be_empty
  end

  it 'cannot have multiple reviews for the same product by the same user' do
    product = FactoryBot.create(:product)
    user = FactoryBot.create(:user)
    FactoryBot.create(:store_review, product:, user:)
    review = FactoryBot.build(:store_review, product:, user:)
    review.valid?
    expect(review.errors[:base]).not_to be_empty
  end
end
