# frozen_string_literal: true

require 'rails_helper'

describe Store::AppPolicy do
  subject { described_class }

  permissions :index?, :more?, :sort?, :create?, :new? do
    it 'denies access if not developer' do
      expect(subject).not_to permit(FactoryBot.create(:user), App)
    end

    it 'grants access if developer' do
      expect(subject).to permit(FactoryBot.create(:user, position: 'developer'), App)
    end

    it 'grants access if admin' do
      expect(subject).to permit(FactoryBot.create(:user, roles: ['Administrator']), App)
    end
  end

  permissions :edit?, :update?, :create_product?, :new_product? do
    let!(:developer) { FactoryBot.create(:user, position: 'developer') }
    let!(:app) { FactoryBot.create(:app, responsible: developer.id) }

    it 'denies access if not developer or admin' do
      expect(subject).not_to permit(FactoryBot.create(:user), app)
    end

    it 'denies access if developer but not owner' do
      expect(subject).not_to permit(FactoryBot.create(:user, position: 'developer'), app)
    end

    it 'grants access if developer and owner' do
      expect(subject).to permit(developer, app)
    end

    it 'grants access if admin' do
      expect(subject).to permit(FactoryBot.create(:user, roles: ['Administrator']), app)
    end
  end
end
