# frozen_string_literal: true

require 'rails_helper'

describe Store::ReviewPolicy do
  subject { described_class }

  permissions :create_review? do
    it 'denies access if not customer' do
      expect(subject).not_to permit(FactoryBot.create(:user), Store::Order)
    end

    it 'grants access if customer' do
      expect(subject).to permit(FactoryBot.create(:user, position: 'customer'), Store::Order)
    end
  end

  permissions :destroy_review? do
    let!(:customer) { FactoryBot.create(:user, position: 'customer') }
    let!(:product) { FactoryBot.create(:product) }
    let!(:review) { FactoryBot.create(:store_review, user_id: customer.id, product:) }

    it 'denies access if not customer' do
      expect(subject).not_to permit(FactoryBot.create(:user), review)
    end

    it 'denies access if customer not owner' do
      expect(subject).not_to permit(FactoryBot.create(:user, position: 'customer'), review)
    end

    it 'grants access if customer and owner' do
      expect(subject).to permit(customer, review)
    end

    it 'grants access if admin' do
      expect(subject).to permit(FactoryBot.create(:user, roles: ['Administrator']), review)
    end
  end
end
