# frozen_string_literal: true

require 'rails_helper'

describe Store::UserPolicy do
  subject { described_class }

  permissions :edit_profile?, :update_profile?, :add_hostname? do
    let!(:user) { FactoryBot.create(:user) }

    it 'denies access if not same user' do
      expect(subject).not_to permit(FactoryBot.create(:user), user)
    end

    it 'grants access if same user' do
      expect(subject).to permit(user, user)
    end

    it 'grants access if admin' do
      expect(subject).to permit(FactoryBot.create(:user, roles: ['Administrator']), user)
    end
  end

  permissions :index?, :more?, :sort?, :edit?, :update?, :block?, :unblock? do
    let!(:user) { FactoryBot.create(:user) }

    it 'denies access if not admin' do
      expect(subject).not_to permit(FactoryBot.create(:user), user)
    end

    it 'grants access if admin' do
      expect(subject).to permit(FactoryBot.create(:user, roles: ['Administrator']), user)
    end
  end
end
